@@ -330,7 +330,11 @@ check.obj <- function(object1, object2) {
       callA <- object1@Call
       ## recommended vcov type for mirt models:
       if(object1@Options$SE.type != "Oakes") warning("SE.type='Oakes' is recommended for mirt models")
-    } else {
+    } 
+      if (classA %in% c("MxRAMModel" , "MxModel")){
+      callA <- object1@name
+    }
+    else {
       callA <- object1@call
     }
     if(classA == "lavaan"){
@@ -345,7 +349,11 @@ check.obj <- function(object1, object2) {
     if(classB %in% c("SingleGroupClass", "MultipleGroupClass")){
       callB <- object2@Call
       if(object2@Options$SE.type != "Oakes") warning("SE.type='Oakes' is recommended for mirt models")
-    } else {
+    } 
+      if (classB %in% c("MxRAMModel" , "MxModel") ){
+      callB <- object2@name
+    }
+    else {
       callB <- object2@call
     }
     if(classB == "lavaan"){
@@ -363,5 +371,5 @@ check.obj <- function(object1, object2) {
 
 .onAttach <- function(...) {
   version <- read.dcf(file=system.file("DESCRIPTION", package="nonnest2"), fields="Version")
-  packageStartupMessage(paste0("This is nonnest2 ", version, ".\nnonnest2 has not been tested with all combinations of model classes."))
+  packageStartupMessage(paste0("This is nonnest2 ", version, ".\nnonnest2 has not been tested with all combinations of supported model classes."))
 }
